# SportIdent Config+ Implementation

A python implementation of the functionality of SPORTident Config+.

Currently only working and tested under Linux.

Note that you might need to add your user to a group that has access to the systems serial interfaces.

## API docs

a part of the api is documented in [Codes.md](docs/Codes.md)
